package com.uas.cloud.mall.shop.news.api;

import com.alibaba.fastjson.JSON;
import com.uas.cloud.mall.shop.news.model.News;
import com.uas.cloud.mall.shop.news.service.NewsService;
import org.apache.commons.collections.CollectionUtils;
import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.client.ServiceInstance;
import org.springframework.cloud.client.discovery.DiscoveryClient;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;

/**
 * 新闻服务api
 *
 * Created by dongbw on 17/02/25.
 */

@RestController
@RequestMapping("/news")
public class NewsController {

    private final Logger logger = LogManager.getLogger(getClass());

    @Autowired
    private DiscoveryClient client;

    @Autowired
    private NewsService newsService;

    /**
     * 根据id获取某条新闻
     *
     * @param id
     * @return
     */
    @RequestMapping(value="/{id}", method = RequestMethod.GET, produces = "application/json")
    public News get(@PathVariable Long id) {
        ServiceInstance instance = client.getLocalServiceInstance();
        logger.info("/news, method: get, host:" + instance.getHost() + ", serviceId:" + instance.getServiceId() + ",news: " + id);
        return newsService.findone(id);
    }

    /**
     *  获取num条最新新闻
     *  version:v2
     * @return
     */
    @RequestMapping(value="/created/v2" ,method = RequestMethod.GET, produces = "application/json")
    public Map<String,Object> getNewsByCreated2(@RequestParam(defaultValue = "1") int pagenumber , @RequestParam(defaultValue = "10") int pagesize , @RequestParam(defaultValue = "B2C") String taxonomySlug) {
        ServiceInstance instance = client.getLocalServiceInstance();
        logger.info("/news, get, host:" + instance.getHost() + ", serviceId:" + instance.getServiceId() + "get news order by created time");
        Map<String,Object> newsList = newsService.findBycreated(pagenumber,pagesize,taxonomySlug);
        return newsList;
    }

    /**
     *  获取最多点击量新闻
     *  version:v2
     * @return
     */
    @RequestMapping(value="/viewcount/v2" ,method = RequestMethod.GET, produces = "application/json")
    public Map<String,Object> getNewsByViewCount2(@RequestParam(defaultValue = "1") int pagenumber , @RequestParam(defaultValue = "10") int pagesize , @RequestParam(defaultValue = "B2C") String taxonomySlug) {
        ServiceInstance instance = client.getLocalServiceInstance();
        logger.info("/news, get, host:" + instance.getHost() + ", serviceId:" + instance.getServiceId() + "get news order by viewcount");
        return newsService.findByViewCount(pagenumber,pagesize,taxonomySlug);
    }

    /**
     *  获取num条最新新闻
     *
     * @return
     */
    @RequestMapping(value="/created" ,method = RequestMethod.GET, produces = "application/json")
    public List<News> getNewsByCreated(@RequestParam(defaultValue = "1") int pagenumber , @RequestParam(defaultValue = "10") int pagesize , @RequestParam(defaultValue = "B2C") String taxonomySlug) {
        ServiceInstance instance = client.getLocalServiceInstance();
        logger.info("/news, get, host:" + instance.getHost() + ", serviceId:" + instance.getServiceId() + "get news order by created time");
        Map<String,Object> newsList = newsService.findBycreated(pagenumber,pagesize,taxonomySlug);
        return  (List<News>) newsList.get("content");
    }

    /**
     *  获取最多点击量新闻
     *
     * @return
     */
    @RequestMapping(value="/viewcount" ,method = RequestMethod.GET, produces = "application/json")
    public List<News> getNewsByViewCount(@RequestParam(defaultValue = "1") int pagenumber , @RequestParam(defaultValue = "10") int pagesize , @RequestParam(defaultValue = "B2C") String taxonomySlug) {
        ServiceInstance instance = client.getLocalServiceInstance();
        logger.info("/news, get, host:" + instance.getHost() + ", serviceId:" + instance.getServiceId() + "get news order by viewcount");
        return (List<News>) newsService.findByViewCount(pagenumber,pagesize,taxonomySlug).get("content");
    }

}
