package com.uas.cloud.mall.shop.news.model;

import com.fasterxml.jackson.annotation.JsonInclude;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 *  资讯
 *
 * Created by dongbw on 17/02/25.
 */
@Entity
@Table(name = "jpress_content")
@JsonInclude(JsonInclude.Include.NON_EMPTY)
public class News{

//    @Value("${application.indexUrl}")
//    private String INDEX_USOFTCHINA;
    private static final String INDEX_USOFTCHINA = "https://uas.usoftchina.com";

    private static final String NEWS_TEXT = "/c/";

    @Id
    @Column(name = "id")
    private Long id;

    /**
     * 标题
     */
    @Column(name = "title")
    private String title;

    /**
     *  摘要
     */
    @Column(name = "summary")
    private String summary;

    /**
     *  内容
     */
    @Column(name = "text")
    private String content;

    /**
     *  缩略图
     */
    @Column(name = "thumbnail")
    private String thumbnail;

    /**
     *  文章点击量（在官网首页的点击量）
     */
    @Column(name = "view_count")
    private Long viewCount;

    /**
     *  文章内容页的url后缀
     *
     */
    @Column(name = "slug")
    private String url_suffix;

    /**
     *  创建时间
     */
    @Column(name = "created")
    private Date created;

    @Column(name = "module")
    private String module;

    /**
     * 最后修改时间
     *
     */
    @Column(name = "modified")
    private Date modified;

    /**
     *  链接地址（进入该文章内容）
     */
    private String hrefUrl;

    public News() {}

    public News(Long id, String title, String summary, String content, String thumbnail, Long viewCount, String url_suffix, Date created, String module, Date modified, String hrefUrl) {
        this.id = id;
        this.title = title;
        this.summary = summary;
        this.content = content;
        this.thumbnail = thumbnail;
        this.viewCount = viewCount;
        this.url_suffix = url_suffix;
        this.created = created;
        this.module = module;
        this.modified = modified;
        this.hrefUrl = hrefUrl;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getThumbnail() {
        if (null != thumbnail && thumbnail.startsWith("/attachment/")) {
            return INDEX_USOFTCHINA + thumbnail;
        }
        return this.thumbnail;
    }

    public void setThumbnail(String thumbnail) {
        this.thumbnail = thumbnail;
    }

    // 跳转到文章详情的URL
    public String getHrefUrl() {
        StringBuffer linkTo = new StringBuffer();
        linkTo.append(INDEX_USOFTCHINA);
        linkTo.append(NEWS_TEXT);
        linkTo.append(this.url_suffix);
        return linkTo.toString();
    }

    public void setHrefUrl(String hrefUrl) {
        this.hrefUrl = hrefUrl;
    }

    public Long getViewCount() {
        return viewCount;
    }

    public void setViewCount(Long viewCount) {
        this.viewCount = viewCount;
    }

    public Date getCreated() {
        return created;
    }

    public void setCreated(Date created) {
        this.created = created;
    }
}
