package com.uas.cloud.mall.shop.news.service.impl;

import com.uas.cloud.mall.shop.news.data.NewsRepository;
import com.uas.cloud.mall.shop.news.model.News;
import com.uas.cloud.mall.shop.news.service.NewsService;
import com.uas.cloud.mall.shop.news.utils.NewsCloumnCutUtil;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.collections.map.HashedMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

import javax.persistence.criteria.Predicate;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by dongbw on 17/02/25 16:05.
 */
@Service
public class NewsServiceImpl implements NewsService {

    @Autowired
    private NewsRepository newsRepository;

    @Override
    @Transactional
    public News findone(Long id) {
        News news = newsRepository.findOne(id);
        newsRepository.addCount(id);
        //判断summary字段是否为空
        if (news != null && StringUtils.isEmpty(news.getSummary())) {
            news.setSummary(NewsCloumnCutUtil.getHtmlText(100,news.getContent()));
        }
        return news;
    }


    @Override
    public Map<String,Object> findBycreated(int pagenumber , int pagesize , String taxonomySlug) {
        Map<String,Object> result = new HashMap();
        List<Long> idByTaxonomySlug = newsRepository.findNewsIdByTaxonomySlug(taxonomySlug);
        if (idByTaxonomySlug != null){
            result.put("count",idByTaxonomySlug.size());
        }
        Pageable pageable = new PageRequest(pagenumber-1 ,pagesize, new Sort(Sort.Direction.DESC, "modified"));
        Page<News> page = newsRepository.findAll((root, query, builder) -> {
            Predicate predicateId = root.get("id").in(idByTaxonomySlug);
            Predicate predicateModule = builder.equal(root.get("module"), "news");
            query.where(predicateId,predicateModule);
            return null;
        }, pageable);
        if (page != null && !CollectionUtils.isEmpty(page.getContent())) {
            result.put("content",NewsCloumnCutUtil.cutText(page.getContent()));
            return result;
        }
        result.put("content",Collections.emptyList());
        return result;
    }


    @Override
    public Map<String,Object> findByViewCount(int pagenumber , int pagesize , String taxonomySlug) {
        Map<String,Object> result = new HashMap();
        List<Long> idByTaxonomySlug = newsRepository.findNewsIdByTaxonomySlug(taxonomySlug);
        if (idByTaxonomySlug != null){
            result.put("count",idByTaxonomySlug.size());
        }
        Pageable pageable = new PageRequest(pagenumber-1 ,pagesize, new Sort(Sort.Direction.DESC, "viewCount"));
        Page<News> page = newsRepository.findAll((root, query, builder) -> {
            Predicate predicateId = root.get("id").in(idByTaxonomySlug);
            Predicate predicateModule = builder.equal(root.get("module"), "news");
            query.where(predicateId,predicateModule);
            return null;
        }, pageable);
        if (page != null && !CollectionUtils.isEmpty(page.getContent())) {
            result.put("content",NewsCloumnCutUtil.cutText(page.getContent()));
            return result;
        }
        result.put("content",Collections.emptyList());
        return result;
    }

}
